hatch_nodejs_version: Hatch plugin for versioning from a package.json file
==========================================================================

Description
-----------

Hatch plugin for versioning from a package.json file

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/hatch-nodejs-version/

